changeset 11668:7fe77b6650cd draft

(svn r16048) -Fix/Feature-ish [FS#2740]: don't warn that crashed vehicles are getting old; upgrading them is impossible (racetrack)
author rubidium <rubidium@openttd.org>
date Sun, 12 Apr 2009 19:28:05 +0000
parents ae9d07bc4bd5
children 6675604f98d0
files src/vehicle.cpp
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/src/vehicle.cpp
+++ b/src/vehicle.cpp
@@ -921,8 +921,8 @@
 
 	InvalidateWindow(WC_VEHICLE_DETAILS, v->index);
 
-	/* Don't warn about non-primary or not ours vehicles */
-	if (v->Previous() != NULL || v->owner != _local_company) return;
+	/* Don't warn about non-primary or not ours vehicles or vehicles that are crashed */
+	if (v->Previous() != NULL || v->owner != _local_company || (v->vehstatus & VS_CRASHED) != 0) return;
 
 	/* Don't warn if a renew is active */
 	if (GetCompany(v->owner)->engine_renew && GetEngine(v->engine_type)->company_avail != 0) return;